About BioSimulators-MASSpy — BioSimulators-MASSpy 0.0.5 documentation

# About BioSimulators-MASSpy

## License

This package is released under the MIT License. MASSpy is released under the MIT.

## Development team

This package was developed by the Karr Lab at the Icahn School of Medicine at Mount Sinai and the Center for Reproducible Biomedical Modeling. MASSpy was developed by the Systems Biology Research Group at the University of California, San Diego.

## Questions and comments

Please contact the BioSimulators Team with any questions or comments about the command-line program or Docker image. Please address questions and comments about MASSpy to Zachary Haiman.